@@ -10,8 +10,11 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-// Check it satisfies the interface
-var _ flagger = (*Time)(nil)
+// Check it satisfies the interfaces
+var (
+	_ flagger   = (*Time)(nil)
+	_ flaggerNP = Time{}
+)
 
 func TestParseTime(t *testing.T) {
 	now := time.Date(2020, 9, 5, 8, 15, 5, 250, time.UTC)
