@@ -1,10 +1,10 @@
 package readers
 
 import (
+	"errors"
 	"io"
 	"testing"
 
-	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 )
 
