@@ -36,8 +36,8 @@ import (
 
 // File represents a file
 type File struct {
-	inode uint64 // inode number - read only
-	size  int64  // size of file - read and written with atomic int64 - must be 64 bit aligned
+	inode uint64       // inode number - read only
+	size  atomic.Int64 // size of file
 
 	muRW sync.Mutex // synchronize RWFileHandle.openPending(), RWFileHandle.close() and File.Remove
 
@@ -51,7 +51,7 @@ type File struct {
 	pendingModTime   time.Time                       // will be applied once o becomes available, i.e. after file was written
 	pendingRenameFun func(ctx context.Context) error // will be run/renamed after all writers close
 	sys              atomic.Value                    // user defined info to be attached here
-	nwriters         int32                           // len(writers) which is read/updated with atomic
+	nwriters         atomic.Int32                    // len(writers)
 	appendMode       bool                            // file was opened with O_APPEND
 }
 
@@ -67,7 +67,7 @@ func newFile(d *Dir, dPath string, o fs.Object, leaf string) *File {
 		inode: newInode(),
 	}
 	if o != nil {
-		f.size = o.Size()
+		f.size.Store(o.Size())
 	}
 	return f
 }
@@ -266,7 +266,7 @@ func (f *File) rename(ctx context.Context, destDir *Dir, newName string) error {
 func (f *File) addWriter(h Handle) {
 	f.mu.Lock()
 	f.writers = append(f.writers, h)
-	atomic.AddInt32(&f.nwriters, 1)
+	f.nwriters.Add(1)
 	f.mu.Unlock()
 }
 
@@ -284,7 +284,7 @@ func (f *File) delWriter(h Handle) {
 	}
 	if found >= 0 {
 		f.writers = append(f.writers[:found], f.writers[found+1:]...)
-		atomic.AddInt32(&f.nwriters, -1)
+		f.nwriters.Add(-1)
 	} else {
 		fs.Debugf(f._path(), "File.delWriter couldn't find handle")
 	}
@@ -295,7 +295,7 @@ func (f *File) delWriter(h Handle) {
 // Note that we don't take the mutex here.  If we do then we can get a
 // deadlock.
 func (f *File) activeWriters() int {
-	return int(atomic.LoadInt32(&f.nwriters))
+	return int(f.nwriters.Load())
 }
 
 // _roundModTime rounds the time passed in to the Precision of the
@@ -383,7 +383,7 @@ func (f *File) Size() int64 {
 
 	// if o is nil it isn't valid yet or there are writers, so return the size so far
 	if f._writingInProgress() {
-		return atomic.LoadInt64(&f.size)
+		return f.size.Load()
 	}
 	return nonNegative(f.o.Size())
 }
@@ -473,7 +473,7 @@ func (f *File) writingInProgress() bool {
 
 // Update the size while writing
 func (f *File) setSize(n int64) {
-	atomic.StoreInt64(&f.size, n)
+	f.size.Store(n)
 }
 
 // Update the object when written and add it to the directory
